@@ -20,10 +20,20 @@ import gzip
 import math
 import datetime
 import time
-import pickle
-import base64
 import importlib.machinery
 from collections import Counter
+from tqdm import tqdm
+
+
+def bar(data):
+    """
+    进度条
+    :param data: 列表 字典 迭代器
+    :return:
+    """
+    if isinstance(data, int):
+        return tqdm(range(data))
+    return tqdm(data)
 
 
 def safe_eval(string):
@@ -43,6 +53,7 @@ def safe_eval(string):
         raise ValueError(f"""错误! 无法转化语句: {string} """)
     return ret
 
+
 def load_py_func(py_name, func_name='pipeline', py_dir='./'):
     """load_py方法用于动态加载py文件
     这加载的是指定的python文件函数
@@ -319,7 +330,7 @@ def get_files(path, extension=None, exclude=None, include=None):
     ret = os.listdir(path)
     if extension:
         length = -len(extension)
-        ret = [path_join(path, each) for each in os.listdir(path) if each[length:] == extension]
+        ret = list(filter(lambda x: x[length:] == extension, ret))
         if not ret:
             return []
     if exclude:
@@ -330,6 +341,7 @@ def get_files(path, extension=None, exclude=None, include=None):
         ret = list(filter(lambda x: include in x, ret))
         if not ret:
             return []
+    ret = [path_join(path, each) for each in ret]
     return ret
 
 
@@ -1157,33 +1169,4 @@ def load_yaml(path, encoding='UTF-8'):
     except:
         with open(path, 'r') as f:
             config = yaml.load(f.read())
-    return config
-
-
-def to_byte(data):
-    """to_byte方法用于将对象转换为字节
-
-    Parameters
-    ----------
-    data : object
-        任意对象
-    Returns
-    ----------
-    """
-    data = base64.b64encode(pickle.dumps(data)).decode("ascii")
-    return data
-
-
-def from_byte(data):
-    """from_byte方法用于将字节对象还原
-
-    Parameters
-    ----------
-    param : str
-
-    Returns
-    ----------
-    """
-    data = base64.b64decode(data)
-    data = pickle.loads(data)
-    return data
\ No newline at end of file
+    return config
\ No newline at end of file
